VirtualVariableDie

Struct VirtualVariableDie 

pub struct VirtualVariableDie {
    pub type_ref: DieAddr,
}
This DIE does not actually exist in debug information. It may be used to represent variables that are declared by user, for example, using pointer cast operator.

Fields

type_ref: DieAddr

Implementations

Source

impl VirtualVariableDie

pub fn workpiece() -> Self

Create blank virtual variable DIE.

pub fn init_with_known_type<'dbg>( &mut self, debug_info: &'dbg DebugInformation, unit_offset: DebugInfoOffset, die_offset: UnitOffset, ) -> Result<FatDieRef<'dbg, Variable>, Error>

Initialize virtual variable with a concrete type. Return reference to virtual DIE.

pub fn init_with_type<'dbg>( &mut self, debugee: &'dbg Debugee, type_name: &str, ) -> Result<FatDieRef<'dbg, Variable>, Error>

Initialize virtual variable with a concrete type. Return reference to virtual DIE.