macro_rules! debug_info_exists {
($expr: expr) => { ... };
}Expand description
Using this macro means a promise that debug information exists in context of usage.
macro_rules! debug_info_exists {
($expr: expr) => { ... };
}Using this macro means a promise that debug information exists in context of usage.