Module command

Module command 

An interface to a debugger. This is the most preferred way to use a debugger functional from UI layer.

Contains commands and corresponding command handlers. Command is a some sort of request to debugger that defines an action and a list of input arguments.

Modules

async
backtrace
break
call
continue
frame
memory
parser
print
register
run
sharedlib
source_code
step_instruction
step_into
step_out
step_over
symbol
thread
trigger
watch

Enums

Command
External commands that can be processed by the debugger.
CommandError

Type Aliases

CommandResult