An interface to a debugger. This is the most preferred way to use a debugger functional from UI layer.
Contains commands and corresponding command handlers. Command is a some sort of request to debugger that defines an action and a list of input arguments.
Modules
- async
- backtrace
- break
- call
- continue
- frame
- memory
- parser
- register
- run
- sharedlib
- source_
code - step_
instruction - step_
into - step_
out - step_
over - symbol
- thread
- trigger
- watch
Enums
- Command
- External commands that can be processed by the debugger.
- Command
Error